Learn R Programming

yfscreen (version 0.1.1)

data_fundfamilyname: Fund Family Name Data for the Yahoo Finance API

Description

A data frame with the available fund family name data for the Yahoo Finance API.

Usage

data_fundfamilyname

Arguments

Format

A data frame.